import dependency_injector.containers as containers
import dependency_injector.providers as providers

from messenger_sdk.config import Config
from messenger_sdk.api_client import ApiClient
from messenger_sdk.events import EventFactory
from messenger_sdk.fb_manager import FbManager
from messenger_sdk.log import Log


class BaseContainer(containers.DeclarativeContainer):
    config = providers.Singleton(Config)
    api_client = providers.Singleton(ApiClient)
    event_factory = providers.Singleton(EventFactory)
    log = providers.Singleton(Log, config)
    fb_manager = providers.Factory(FbManager, api_client, config)



import requests
from messenger_sdk.templates import BaseTemplate


class Api:
    def __init__(self, access_token, api_version=2.6):
        self.access_token = access_token
        self.api_version = api_version
        self.endpoint = "https://graph.facebook.com/v{0}/me/messages?access_token={1}".format(
            self.api_version,
            self.access_token
        )

    def send_message(self, message: BaseTemplate):
        return self._send_message_request(message.get_template())

    def _send_message_request(self, payload):
        response = requests.post(self.endpoint, json=payload).json()

        return response
